==> liquidwar_5.4.5.orig.tar.gz: liquidwar-5.4.5.orig/src/joystick.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/*****************************************************************************/
/* Liquid War is a unique multiplayer wargame                                */
/* Copyright (C) 1998-2002 Christian Mauduit                                 */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*                                                                           */
/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
/* Contact author      : ufoot@ufoot.org                                     */
/*****************************************************************************/

/********************************************************************/
/* nom           : joystick.c                                       */
/* contenu       : gestion du joystick                              */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <allegro.h>

#include "config.h"
#include "joystick.h"
#include "startup.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/

/*------------------------------------------------------------------*/
int my_initialise_joystick (void)
{
 #ifdef ALLEGRO_DOS
	#define JOY_TYPE0 JOY_TYPE_2PADS
	#define JOY_TYPE1 JOY_TYPE_4BUTTON
	#define JOY_TYPE2 JOY_TYPE_STANDARD
 #endif

 #ifdef ALLEGRO_WINDOWS
	#define JOY_TYPE0 JOY_TYPE_AUTODETECT
	#define JOY_TYPE1 JOY_TYPE_AUTODETECT
	#define JOY_TYPE2 JOY_TYPE_AUTODETECT
 #endif

 #ifdef ALLEGRO_UNIX
	#define JOY_TYPE0 JOY_TYPE_AUTODETECT
	#define JOY_TYPE1 JOY_TYPE_AUTODETECT
	#define JOY_TYPE2 JOY_TYPE_AUTODETECT
 #endif

	if (STARTUP_JOYSTICK_ON)
    {
#ifdef joy_type
     switch (CONFIG_JOYSTICK_ON)
        {
         case 1: joy_type=JOY_TYPE0;
                 break;
         case 2: joy_type=JOY_TYPE1;
                 break;
         case 3: joy_type=JOY_TYPE2;
                 break;
        }
#endif
     return initialise_joystick ();
    }
 else
     return -1;
}

/*------------------------------------------------------------------*/
void my_poll_joystick (void)
{
 if (CONFIG_JOYSTICK_ON && STARTUP_JOYSTICK_ON)
    poll_joystick();
}

==> liquidwar-5.6.0.tar.gz: liquidwar-5.6.0/src/joystick.c <==
/********************************************************************/
/*                                                                  */
/*            L   I  QQ  U U I DD    W   W  A  RR    555            */
/*            L   I Q  Q U U I D D   W   W A A R R   5              */
/*            L   I Q  Q U U I D D   W W W AAA RR    55             */
/*            L   I Q Q  U U I D D   WW WW A A R R     5            */
/*            LLL I  Q Q  U  I DD    W   W A A R R   55             */
/*                                                                  */
/*                             b                                    */
/*                             bb  y y                              */
/*                             b b yyy                              */
/*                             bb    y                              */
/*                                 yy                               */
/*                                                                  */
/*                     U U       FFF  O   O  TTT                    */
/*                     U U       F   O O O O  T                     */
/*                     U U TIRET FF  O O O O  T                     */
/*                     U U       F   O O O O  T                     */
/*                      U        F    O   O   T                     */
/*                                                                  */
/********************************************************************/

/*****************************************************************************/
/* Liquid War is a multiplayer wargame                                       */
/* Copyright (C) 1998-2003 Christian Mauduit                                 */
/*                                                                           */
/* This program is free software; you can redistribute it and/or modify      */
/* it under the terms of the GNU General Public License as published by      */
/* the Free Software Foundation; either version 2 of the License, or         */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software               */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
/*                                                                           */
/* Liquid War homepage : http://www.ufoot.org/liquidwar                      */
/* Contact author      : ufoot@ufoot.org                                     */
/*****************************************************************************/

/********************************************************************/
/* nom           : joystick.c                                       */
/* contenu       : gestion du joystick                              */
/* date de modif : 3 mai 98                                         */
/********************************************************************/

/*==================================================================*/
/* includes                                                         */
/*==================================================================*/

#include <allegro.h>

#include "config.h"
#include "joystick.h"
#include "startup.h"

/*==================================================================*/
/* variables globales                                               */
/*==================================================================*/

/*==================================================================*/
/* fonctions                                                        */
/*==================================================================*/

/*------------------------------------------------------------------*/
int
my_initialise_joystick (void)
{
#ifdef ALLEGRO_DOS
#define JOY_TYPE0 JOY_TYPE_2PADS
#define JOY_TYPE1 JOY_TYPE_4BUTTON
#define JOY_TYPE2 JOY_TYPE_STANDARD
#endif

#ifdef ALLEGRO_WINDOWS
#define JOY_TYPE0 JOY_TYPE_AUTODETECT
#define JOY_TYPE1 JOY_TYPE_AUTODETECT
#define JOY_TYPE2 JOY_TYPE_AUTODETECT
#endif

#ifdef ALLEGRO_UNIX
#define JOY_TYPE0 JOY_TYPE_AUTODETECT
#define JOY_TYPE1 JOY_TYPE_AUTODETECT
#define JOY_TYPE2 JOY_TYPE_AUTODETECT
#endif

  if (STARTUP_JOYSTICK_ON)
    {
#ifdef joy_type
      switch (CONFIG_JOYSTICK_ON)
	{
	case 1:
	  joy_type = JOY_TYPE0;
	  break;
	case 2:
	  joy_type = JOY_TYPE1;
	  break;
	case 3:
	  joy_type = JOY_TYPE2;
	  break;
	}
#endif
      return initialise_joystick ();
    }
  else
    return -1;
}

/*------------------------------------------------------------------*/
void
my_poll_joystick (void)
{
  if (CONFIG_JOYSTICK_ON && STARTUP_JOYSTICK_ON)
    poll_joystick ();
}
